# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MSAcquisition.SampleInfoRW

class AgtSampleInfo(
    Agilent.MSAcquisition.SampleInfoRW.IAgtSampleInfoReader,
    Agilent.MSAcquisition.SampleInfoRW.IAgtSampleInfoWriter,
    Agilent.MSAcquisition.SampleInfoRW.IAgtSampleInfoXMLStringMgr,
):  # Class
    def __init__(self) -> None: ...

class DeviceConfigInformation(
    System.IDisposable,
    System.ComponentModel.IListSource,
    System.Xml.Serialization.IXmlSerializable,
    System.ComponentModel.ISupportInitializeNotification,
    System.ComponentModel.IComponent,
    System.ComponentModel.ISupportInitialize,
    System.IServiceProvider,
    System.Runtime.Serialization.ISerializable,
    Agilent.MSAcquisition.SampleInfoRW.IDeviceConfigDataMgr,
    System.Data.DataSet,
):  # Class
    def __init__(self) -> None: ...

    Device: (
        Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceDataTable
    )  # readonly
    DeviceConfigInfo: (
        Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoDataTable
    )  # readonly
    Parameter: (
        Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterDataTable
    )  # readonly
    Relations: System.Data.DataRelationCollection  # readonly
    SchemaSerializationMode: System.Data.SchemaSerializationMode
    Tables: System.Data.DataTableCollection  # readonly

    def WriteDeviceConfig(self, dataFilePath: str) -> None: ...
    @staticmethod
    def GetTypedDataSetSchema(
        xs: System.Xml.Schema.XmlSchemaSet,
    ) -> System.Xml.Schema.XmlSchemaComplexType: ...
    def ReadDeviceConfig(self, dataFilePath: str) -> None: ...
    def Clone(self) -> System.Data.DataSet: ...

    # Nested Types

    class DeviceConfigInfoDataTable(
        System.IDisposable,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.ISupportInitializeNotification,
        System.ComponentModel.IComponent,
        Iterable[Any],
        System.Data.DataTable,
        System.IServiceProvider,
        System.ComponentModel.ISupportInitialize,
        System.Runtime.Serialization.ISerializable,
        System.ComponentModel.IListSource,
    ):  # Class
        def __init__(self) -> None: ...

        Count: int  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRow
        ): ...
        VersionColumn: System.Data.DataColumn  # readonly

        def GetEnumerator(self) -> Iterator[Any]: ...
        @overload
        def AddDeviceConfigInfoRow(
            self,
            row: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRow,
        ) -> None: ...
        @overload
        def AddDeviceConfigInfoRow(
            self, Version: str
        ) -> (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRow
        ): ...
        def NewDeviceConfigInfoRow(
            self,
        ) -> (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRow
        ): ...
        def RemoveDeviceConfigInfoRow(
            self,
            row: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRow,
        ) -> None: ...
        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def Clone(self) -> System.Data.DataTable: ...

        DeviceConfigInfoRowChanged: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRowChangeEventHandler
        )  # Event
        DeviceConfigInfoRowChanging: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRowChangeEventHandler
        )  # Event
        DeviceConfigInfoRowDeleted: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRowChangeEventHandler
        )  # Event
        DeviceConfigInfoRowDeleting: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRowChangeEventHandler
        )  # Event

    class DeviceConfigInfoRow(System.Data.DataRow):  # Class
        Version: str

        def SetVersionNull(self) -> None: ...
        def IsVersionNull(self) -> bool: ...

    class DeviceConfigInfoRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRow
        )  # readonly

    class DeviceConfigInfoRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceConfigInfoRowChangeEvent,
        ) -> None: ...

    class DeviceDataTable(
        System.IDisposable,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.ISupportInitializeNotification,
        System.ComponentModel.IComponent,
        Iterable[Any],
        System.Data.DataTable,
        System.IServiceProvider,
        System.ComponentModel.ISupportInitialize,
        System.Runtime.Serialization.ISerializable,
        System.ComponentModel.IListSource,
    ):  # Class
        def __init__(self) -> None: ...

        Count: int  # readonly
        DeviceIDColumn: System.Data.DataColumn  # readonly
        DisplayNameColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRow: ...
        def GetEnumerator(self) -> Iterator[Any]: ...
        def RemoveDeviceRow(
            self,
            row: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRow,
        ) -> None: ...
        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def NewDeviceRow(
            self,
        ) -> Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRow: ...
        def FindByDeviceID(
            self, DeviceID: str
        ) -> Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRow: ...
        @overload
        def AddDeviceRow(
            self,
            row: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRow,
        ) -> None: ...
        @overload
        def AddDeviceRow(
            self, DeviceID: str, DisplayName: str
        ) -> Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRow: ...
        def Clone(self) -> System.Data.DataTable: ...

        DeviceRowChanged: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRowChangeEventHandler
        )  # Event
        DeviceRowChanging: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRowChangeEventHandler
        )  # Event
        DeviceRowDeleted: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRowChangeEventHandler
        )  # Event
        DeviceRowDeleting: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRowChangeEventHandler
        )  # Event

    class DeviceRow(System.Data.DataRow):  # Class
        DeviceID: str
        DisplayName: str

        def SetDisplayNameNull(self) -> None: ...
        def GetParameterRows(
            self,
        ) -> List[
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRow
        ]: ...
        def IsDisplayNameNull(self) -> bool: ...

    class DeviceRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRow
        )  # readonly

    class DeviceRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRowChangeEvent,
        ) -> None: ...

    class ParameterDataTable(
        System.IDisposable,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.ISupportInitializeNotification,
        System.ComponentModel.IComponent,
        Iterable[Any],
        System.Data.DataTable,
        System.IServiceProvider,
        System.ComponentModel.ISupportInitialize,
        System.Runtime.Serialization.ISerializable,
        System.ComponentModel.IListSource,
    ):  # Class
        def __init__(self) -> None: ...

        Count: int  # readonly
        DeviceIDColumn: System.Data.DataColumn  # readonly
        DisplayNameColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRow
        ): ...
        ResourceIDColumn: System.Data.DataColumn  # readonly
        ResourceNameColumn: System.Data.DataColumn  # readonly
        UnitsColumn: System.Data.DataColumn  # readonly
        ValueColumn: System.Data.DataColumn  # readonly

        def GetEnumerator(self) -> Iterator[Any]: ...
        @overload
        def AddParameterRow(
            self,
            row: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRow,
        ) -> None: ...
        @overload
        def AddParameterRow(
            self,
            parentDeviceRowByDevice_Parameter: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRow,
            ResourceName: str,
            ResourceID: str,
            Value: str,
            Units: str,
            DisplayName: str,
        ) -> (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRow
        ): ...
        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def NewParameterRow(
            self,
        ) -> (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRow
        ): ...
        def RemoveParameterRow(
            self,
            row: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRow,
        ) -> None: ...
        def Clone(self) -> System.Data.DataTable: ...

        ParameterRowChanged: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRowChangeEventHandler
        )  # Event
        ParameterRowChanging: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRowChangeEventHandler
        )  # Event
        ParameterRowDeleted: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRowChangeEventHandler
        )  # Event
        ParameterRowDeleting: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRowChangeEventHandler
        )  # Event

    class ParameterRow(System.Data.DataRow):  # Class
        DeviceID: str
        DeviceRow: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.DeviceRow
        DisplayName: str
        ResourceID: str
        ResourceName: str
        Units: str
        Value: str

        def IsUnitsNull(self) -> bool: ...
        def SetResourceNameNull(self) -> None: ...
        def IsDisplayNameNull(self) -> bool: ...
        def SetResourceIDNull(self) -> None: ...
        def SetValueNull(self) -> None: ...
        def IsDeviceIDNull(self) -> bool: ...
        def SetDeviceIDNull(self) -> None: ...
        def SetDisplayNameNull(self) -> None: ...
        def IsResourceNameNull(self) -> bool: ...
        def IsResourceIDNull(self) -> bool: ...
        def SetUnitsNull(self) -> None: ...
        def IsValueNull(self) -> bool: ...

    class ParameterRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRow
        )  # readonly

    class ParameterRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MSAcquisition.SampleInfoRW.DeviceConfigInformation.ParameterRowChangeEvent,
        ) -> None: ...

class IAgtSampleInfoReader(object):  # Interface
    def SetSchemaPath(self, SchemaPath: str) -> None: ...
    def GetSampleInfo(
        self,
        DataFilePath: str,
        ProcessingMode: str,
        ArrSystemNames: List[str],
        ArrDisplayNames: List[str],
        ArrDataValues: List[str],
        ArrDataType: List[int],
        ArrUnits: List[str],
    ) -> None: ...

class IAgtSampleInfoWriter(object):  # Interface
    def SaveSampleInfo(
        self,
        DataFilePath: str,
        ProcessingMode: str,
        ArrSystemNames: List[str],
        ArrDisplayNames: List[str],
        ArrDataValues: List[str],
        ArrDataType: List[int],
        ArrUnits: List[str],
    ) -> None: ...

class IAgtSampleInfoXMLStringMgr(object):  # Interface
    def CreateSampleInfoXMLString(self, SampleInfoXMLString: str) -> None: ...
    def SetSchemaPath(self, SchemaPath: str) -> None: ...
    def GetSampleInfo(
        self,
        ArrSystemNames: List[str],
        ArrDisplayNames: List[str],
        ArrDataValues: List[str],
        ArrDataType: List[str],
        ArrUnits: List[str],
        ArrFieldType: List[str],
    ) -> None: ...
    def LoadSampleInfoXMLStringIntoCache(
        self, FilePath: str, SampleInfoXMLString: str
    ) -> None: ...
    def SaveSampleInfoFromCache(self, FilePath: str) -> None: ...
    def SaveSampleInfoXMLString(
        self, SampleInfoXMLString: str, FilePath: str
    ) -> None: ...
    def CacheSampleInfoFromXMLString(self, SampleInfoXMLString: str) -> None: ...
    def UpdateSampleInfoField(self, Name: str, Value: str) -> None: ...
    def AddSampleInfoField(
        self,
        Name: str,
        DisplayName: str,
        Value: str,
        DataType: str,
        Units: str,
        FieldType: str,
    ) -> None: ...
    def ClearSaveXMLString(self) -> None: ...
    def GetSampleInfoField(
        self,
        Name: str,
        DisplayName: str,
        Value: str,
        DataType: str,
        Units: str,
        FieldType: str,
    ) -> None: ...

class IDeviceConfigDataMgr(object):  # Interface
    def ReadDeviceConfig(self, dataFilePath: str) -> None: ...
    def WriteDeviceConfig(self, dataFilePath: str) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Agilent.MassSpectrometry.DataAnalysis.MassHunter import CompoundFilterParameters
from .BasicTypes import (
    ChromMetadata,
    MfeCompound,
    PeakList,
    SampleChemistryInfo,
    XYCollectionLine,
)
from .Mathematics import RangeDouble, RangeInt
from .PersistanceFiles import SpectralPeakStorage

# Stubs for namespace: MhdFile

class ExtractorUserParameters:  # Class
    def __init__(self) -> None: ...

    DefaultMaxSpectralPeakCount: int  # static # readonly
    MaxSpectralPeakCount: int
    SampleChemistryInfo: SampleChemistryInfo

    C13IsotopePattern: bool  # readonly
    MaxChargeCount: int  # readonly
    SaltDominated: bool  # readonly

    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(self, p: MhdFile.ExtractorUserParameters) -> bool: ...
    def GetHashCode(self) -> int: ...
    def Clone(self) -> MhdFile.ExtractorUserParameters: ...

class P3DFile:  # Class
    def __init__(self) -> None: ...
    @overload
    @staticmethod
    def ReadCompounds(
        filePath: str,
        filters: CompoundFilterParameters,
        infoLevel: MfeCompound.InfoLevel,
    ) -> List[MfeCompound]: ...
    @overload
    @staticmethod
    def ReadCompounds(
        filePath: str,
        compoundStorageOffse: int,
        requestedLevel: MfeCompound.InfoLevel,
        useAveragine: bool,
        filterParameters: CompoundFilterParameters,
        compoundFormatVersion: int,
        scanWidths: List[float],
    ) -> List[MfeCompound]: ...
    @overload
    @staticmethod
    def ReadCompounds(
        filePath: str,
        compoundStorageOffse: int,
        requestedLevel: MfeCompound.InfoLevel,
        useAveragine: bool,
        compoundFormatVersion: int,
        scanWidth: List[float],
    ) -> System.Collections.Generic.List[MfeCompound]: ...
    @staticmethod
    def ReadHeaders(filePath: str) -> MhdFile.P3DFile.FileInfo: ...
    @overload
    @staticmethod
    def ReadSpectralPeaks(
        filePath: str,
        fileInfo: MhdFile.P3DFile.FileInfo,
        scanRange: RangeInt,
        mzRange: RangeDouble,
    ) -> System.Collections.Generic.List[PeakList]: ...
    @overload
    @staticmethod
    def ReadSpectralPeaks(
        filePath: str, fileInfo: MhdFile.P3DFile.FileInfo, scanRange: RangeInt
    ) -> SpectralPeakStorage: ...
    @staticmethod
    def ReadXYCollection(
        filePath: str, rtRange: RangeDouble, fileInfo: MhdFile.P3DFile.FileInfo
    ) -> XYCollectionLine: ...

    # Nested Types

    class FileInfo:  # Class
        def __init__(self) -> None: ...

        AlgorithmVersion: int
        CalibCoeffCount: int
        CompoundFormatVersion: int
        FileSize: int
        HunterParameters: MhdFile.ExtractorUserParameters
        Metadata: ChromMetadata
        PeakCount: int
        PeakFindingParameters: MhdFile.P3DFile.PeakFindingParameters
        PeakFormatVersion: int
        SpectralPeakFinderVersion: int
        Version: int

        CompoundBlockOffset: int  # readonly
        CompoundsAreAvailable: bool  # readonly

    class PeakFindingParameters:  # Class
        def __init__(self) -> None: ...

        MZRange: RangeDouble
        PeakPickingThresold: float
        RTRange: RangeDouble
        ThresholdType: int

        @staticmethod
        def Validate(
            userParameters: MhdFile.P3DFile.PeakFindingParameters,
            metadata: ChromMetadata,
        ) -> str: ...
        def Clone(self) -> MhdFile.P3DFile.PeakFindingParameters: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Utils import CultureItem
from .ViewModel import (
    IColumnLabelsViewModel,
    IControlPanelViewModel,
    ITask,
    TaskViewModelBase,
)

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.ColumnLabels

class BindingProxy(System.Windows.ISealable, System.Windows.Freezable):  # Class
    def __init__(self) -> None: ...

    DataProperty: System.Windows.DependencyProperty  # static # readonly

    Data: Any

class CaptionColorConverter(System.Windows.Data.IValueConverter):  # Class
    def __init__(self) -> None: ...
    def ConvertBack(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...
    def Convert(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...

class ColumnLabelItem(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Startup.Edit.ColumnLabels.ColumnLabelsViewModel,
        instrumentType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType,
        relation: str,
        column: str,
    ) -> None: ...

    Caption: str
    CaptionJa: str
    CaptionRu: str
    CaptionZhHans: str
    Column: str  # readonly
    IsCaptionDefault: bool  # readonly
    IsCaptionJaDefault: bool  # readonly
    IsCaptionRuDefault: bool  # readonly
    IsCaptionZhHansDefault: bool  # readonly
    IsHidden: bool

    def GetCaption(
        self, culture: System.Globalization.CultureInfo, caption: str
    ) -> str: ...

class ColumnLabelsView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class ColumnLabelsViewModel(
    TaskViewModelBase,
    IColumnLabelsViewModel,
    ITask,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self, rootModel: IControlPanelViewModel) -> None: ...

    DefaultColumnVisibilityProperty: System.Windows.DependencyProperty  # static
    JAColumnVisibilityProperty: System.Windows.DependencyProperty  # static
    RUColumnVisibilityProperty: System.Windows.DependencyProperty  # static
    SelectedLanguageProperty: System.Windows.DependencyProperty  # static
    SelectedRelationProperty: System.Windows.DependencyProperty  # static
    ZHColumnVisibilityProperty: System.Windows.DependencyProperty  # static

    ColumnLabelItems: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.ColumnLabels.ColumnLabelItem
    ]
    CommandCheckAll: System.Windows.Input.ICommand  # readonly
    CommandUncheckAll: System.Windows.Input.ICommand  # readonly
    Content: System.Windows.UIElement  # readonly
    DefaultColumnVisibility: System.Windows.Visibility
    Initializing: bool  # readonly
    IsEnabled: bool  # readonly
    JAColumnVisibility: System.Windows.Visibility
    Languages: List[CultureItem]  # readonly
    RUColumnVisibility: System.Windows.Visibility
    Relations: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.ColumnLabels.RelationItem
    ]  # readonly
    SelectedLanguage: str
    SelectedRelation: (
        Agilent.MassHunter.Quantitative.Startup.Edit.ColumnLabels.RelationItem
    )
    Title: str  # readonly
    View: (
        Agilent.MassHunter.Quantitative.Startup.Edit.ColumnLabels.ColumnLabelsView
    )  # readonly
    ZHColumnVisibility: System.Windows.Visibility

    def ResetToDefault(self) -> None: ...
    def Reload(self) -> None: ...
    def IsDirty(self) -> bool: ...
    def Activate(self) -> None: ...
    def GetTools(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools: ...

    PropertyChanged: System.ComponentModel.PropertyChangedEventHandler  # Event

class RelationItem:  # Class
    def __init__(self, relation: str, table: str) -> None: ...

    DisplayName: str  # readonly
    Relation: str  # readonly
    Table: str  # readonly

class ToolHandler(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import UI, IChromatogram, IChromPeak, IDataAccess, IPSetExtractChrom, ISpectrum
from .Quantitative import Signal

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation

class AppException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class BackgroundSubtractionOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    BestScanWithinRange: (
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.BackgroundSubtractionOption
    ) = ...  # static # readonly
    Front: (
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.BackgroundSubtractionOption
    ) = ...  # static # readonly
    HigherOfTwoEnds: (
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.BackgroundSubtractionOption
    ) = ...  # static # readonly
    Rear: (
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.BackgroundSubtractionOption
    ) = ...  # static # readonly

class BreakdownCompound(
    Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.Compound
):  # Class
    def __init__(self) -> None: ...

    BreakdownLimit: float
    IsParentCompound: bool
    ParentCompoundName: str

class BreakdownCompoundResult(
    Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.CompoundResult
):  # Class
    def __init__(self) -> None: ...

    BreakdownLimit: float
    BreakdownPercentage: float
    TicArea: float

class Compound:  # Class
    def __init__(self) -> None: ...

    CompoundName: str
    DeltaRT: float
    ExpectedRT: float
    QualIons: List[float]
    QuantIon: float
    SignalInstance: str
    SignalName: str
    SignalType: str
    _QualIons: str

class CompoundResult:  # Class
    def __init__(self) -> None: ...

    CompoundName: str
    EICs: List[IChromatogram]
    ExpectedRT: float
    ObservedRT: float
    Pass: bool
    Signal: Signal
    Spectrum: ISpectrum
    TICPeak: IChromPeak

class CriteriaEntry:  # Class
    def __init__(self) -> None: ...

    AltBaseOK: bool
    RatioHigherLimit: float
    RatioLowerLimit: float
    RelToMass: float
    TargetMass: float

class ResultEntry:  # Class
    def __init__(self) -> None: ...

    Pass: bool
    RatioHigherLimit: float
    RatioLowerLimit: float
    RawAbundance: float
    RelAbundance: float
    RelToMass: float
    TargetMass: float

class SampleDataNavigator(System.IDisposable):  # Class
    def __init__(self, sampleDataDir: str) -> None: ...

    CurrentRT: float  # readonly
    DataAccess: IDataAccess  # readonly
    SampleDataDir: str  # readonly

    def GetAcquiredSignals(self) -> List[Signal]: ...
    def Dispose(self) -> None: ...
    @overload
    def GetTIC(self) -> System.Collections.Generic.List[IChromatogram]: ...
    @overload
    def GetTIC(self, signal: Signal) -> IChromatogram: ...

class SampleInfo:  # Class
    def __init__(self) -> None: ...

    AcqMethodPath: str
    AcqTime: System.DateTime
    Comment: str
    InstrumentName: str
    Mulitplier: str
    Operator: str
    SampleName: str
    Vial: str

class SampleInfoFile:  # Class
    def __init__(self, sampleFilePath: str) -> None: ...

    AcqDateTime: str
    AcqMethodPath: str
    Comment: str
    InstrumentName: str
    Multiplier: str
    OperatorName: str
    SampleName: str
    Vial: str

class SpectrumExtractionOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Apex: (
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.SpectrumExtractionOption
    ) = ...  # static # readonly
    AverageOfEntirePeak: (
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.SpectrumExtractionOption
    ) = ...  # static # readonly
    ThreeScanAverage: (
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.SpectrumExtractionOption
    ) = ...  # static # readonly

class TailingCompound(
    Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.Compound
):  # Class
    def __init__(self) -> None: ...

    TailingFactorLimit: float

class TailingCompoundResult(
    Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.CompoundResult
):  # Class
    def __init__(self) -> None: ...

    PeakGaussianFactor: float
    TailingFactor: float
    TailingLimit: float

class TuneEvaluationMethod:  # Class
    def __init__(self) -> None: ...

    SCHEMA_VERSION: int = ...  # static # readonly

    AltBaseMZ: float
    BackgroundScanOffsetLeft: int
    BackgroundScanOffsetRight: int
    BackgroundSubtractionOption: str
    BaseMZ: float
    Breakdown: bool
    BreakdownCompounds: List[
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.BreakdownCompound
    ]
    CriteriaEntries: List[
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.CriteriaEntry
    ]
    SchemaVersion: int
    SpectrumAutoEvaluation: bool
    SpectrumExtractionOption: str
    Tailing: bool
    TailingCompounds: List[
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.TailingCompound
    ]
    TuneCompound: str
    TuneEvaluation: bool

    @staticmethod
    def Load(
        path: str,
    ) -> Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.TuneEvaluationMethod: ...
    def Save(self, path: str) -> None: ...

class TuneEvaluationResult:  # Class
    def __init__(self) -> None: ...

    BackgroundSubtractUsed: str
    BreakdownResults: List[
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.BreakdownCompoundResult
    ]
    ResultEntries: List[
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.ResultEntry
    ]
    SampleInfo: Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.SampleInfo
    SamplePath: str
    Spectrum: ISpectrum
    SpectrumAutoEvaluation: bool
    SpectrumExtractionUsed: str
    TailingResults: List[
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.TailingCompoundResult
    ]

    @staticmethod
    def Load(
        path: str,
    ) -> Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.TuneEvaluationResult: ...
    def Save(self, path: str) -> None: ...

class TuneEvaluator:  # Class
    def __init__(
        self,
        samplePath: str,
        method: Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.TuneEvaluationMethod,
    ) -> None: ...

    MZEXTRACTIONWINDOW_LEFT: float = ...  # static # readonly
    MZEXTRACTIONWINDOW_RIGHT: float = ...  # static # readonly

    def Evaluate(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.TuneEvaluationResult: ...
    def GetPSetForTotalSignal(self, signal: Signal) -> IPSetExtractChrom: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models

class IAppCommandContext(
    Agilent.MassSpectrometry.CommandModel.Model.ICommandHistory, System.IDisposable
):  # Interface
    BatchGlobalFeatureAnalysis: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.DynamicQuant.BatchGlobalFeatureAnalysis
    )  # readonly
    IsBatchOpen: bool  # readonly
    MethodDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDataSet
    )  # readonly
    QuantAppCommandContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AppCommandContext
    )  # readonly

    def RemoveCalibrationRange(
        self, targetCompoundID: int, calibrationRangeID: int
    ) -> None: ...
    def CloseBatch(self) -> None: ...
    def NewCalibrationRange(
        self, targetCompoundID: int
    ) -> (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.ICalibrationRange
    ): ...
    def SaveMethod(self, pathName: str) -> None: ...
    def AddCalibrationRange(
        self,
        range: Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.ICalibrationRange,
    ) -> None: ...
    def OpenBatch(self, batchFolder: str, batchFile: str, analyze: bool) -> None: ...
    def GetCalibrationRanges(
        self, targetCompoundID: int
    ) -> List[
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.ICalibrationRange
    ]: ...
    def GetCalibrationRange(
        self, targetCompoundID: int, calibrationRangeID: int
    ) -> (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.ICalibrationRange
    ): ...

    Analyzed: System.EventHandler  # Event
    Analyzing: System.EventHandler  # Event
    BatchClosed: System.EventHandler  # Event
    BatchOpened: System.EventHandler  # Event
    CalibrationRangesChanged: System.EventHandler  # Event
    Progress: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ProgressEventArgs
    ]  # Event

class ICalibrationRange(object):  # Interface
    CalibrationRangeID: int  # readonly
    MaxConcentration: Optional[float]
    MinConcentration: Optional[float]
    QualifierIonGroupIDs: List[int]  # readonly
    TargetCompoundID: int  # readonly
    TargetIonGroupID: Optional[int]

    def AddQualifierIonGroupID(self, id: int) -> None: ...
    def RemoveQualifierIonGroupID(self, id: int) -> None: ...

class ICalibrationRangeItem(object):  # Interface
    CalibrationRangeID: int  # readonly
    MaxConcentration: Optional[float]  # readonly
    MinConcentration: Optional[float]  # readonly
    QualifierIonGroupIDs: List[int]  # readonly
    TargetCompoundID: int  # readonly
    TargetIonGroupID: Optional[int]  # readonly

class ICalibrationRangeViewModel(object):  # Interface
    DynamicCalibrationSetupModel: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IDynamicCalibrationSetupModel
    )  # readonly

class ICalibrationViewModel(object):  # Interface
    Calibration: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.CalibrationRow
    ]  # readonly
    DynamicCalibrationSetupModel: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IDynamicCalibrationSetupModel
    )  # readonly

    def SetSort(self, sortColumn: str, ascending: bool) -> None: ...

class ICompoundsViewModel(object):  # Interface
    DynamicCalibrationSetupModel: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IDynamicCalibrationSetupModel
    )  # readonly
    TargetCompound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundDataTable
    )  # readonly

class IDynamicCalibrationSetupModel(System.IDisposable):  # Interface
    AppCommandContext: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IAppCommandContext
    )  # readonly
    CalibrationRangeViewModel: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.ICalibrationRangeViewModel
    )  # readonly
    CalibrationRanges: List[
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.ICalibrationRangeItem
    ]  # readonly
    CalibrationViewModel: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.ICalibrationViewModel
    )  # readonly
    CompoundsViewModel: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.ICompoundsViewModel
    )  # readonly
    CurrentCalibrationRange: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.ICalibrationRangeItem
    )
    CurrentCompound: System.Data.DataRowView
    CurrentIonGroup: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IIonGroupItem
    )
    IonGroupViewModel: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IIonGroupViewModel
    )  # readonly
    IonGroups: List[
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IIonGroupItem
    ]  # readonly
    QualifiersViewModel: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IQualifiersViewModel
    )  # readonly
    Window: System.Windows.Window

class IIonGroupGraphicsViewModel(object):  # Interface
    DynamicCalibrationSetupModel: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IDynamicCalibrationSetupModel
    )  # readonly

class IIonGroupItem(object):  # Interface
    ConcentrationRangeString: str  # readonly
    CrossSampleIonGroup: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.DynamicQuant.ICrossSampleIonGroup
    )  # readonly
    IonGroupID: int  # readonly
    TargetCompoundID: int  # readonly

class IIonGroupPlotSeries(
    Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries
):  # Interface
    Item: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IIonGroupItem
    )  # readonly

class IIonGroupViewModel(object):  # Interface
    DynamicCalibrationSetupModel: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IDynamicCalibrationSetupModel
    )  # readonly

class IQualifiersViewModel(object):  # Interface
    DynamicCalibrationSetupModel: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.Models.IDynamicCalibrationSetupModel
    )  # readonly
    TargetQualifier: System.Data.DataView  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    AppCommandContext,
    BatchAttributes,
    BatchDataSet,
    BracketingType,
    CalibrationCurveFit,
    CalibrationLevel,
    CompoundType,
    IBatchRow,
    ICalibrationRow,
    ICustomExpressions,
    IMSDataAccess,
    IQuantDataSet,
    IScriptableBatch,
    IScriptableCompound,
    IScriptableQualifierIon,
    IScriptableQuantifierIon,
    IScriptableSample,
    ITargetCompoundRow,
    OptimizedQuantDataSet,
    QuantitationDataSet,
    RowIdBase,
    SampleType,
    SpectrumExtractionOverride,
    TargetCompoundRowId,
    TargetQualifierRowId,
)
from .Compliance import ICompliance

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis

class AnalysisContext:  # Class
    BatchDataSet: QuantitationDataSet  # readonly

    def GetTargetCompoundChromatogram(
        self, batchId: int, sampleId: int, compoundId: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...
    def NotifyAnalysisStart(self, totalSteps: int) -> None: ...
    def NotifyAnalysisEnd(self) -> None: ...
    def NotifyAnalysisStep(self, step: int, analysisTarget: str) -> None: ...
    def GetBatchFilePath(self, batchId: int) -> str: ...
    def MergeBatchDataSet(self, dataset: QuantitationDataSet, batchId: int) -> None: ...
    def GetTargetQualifierChromatogram(
        self, batchId: int, sampleId: int, compoundId: int, qualifierId: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...

class Batch(
    System.IDisposable,
    IScriptableBatch,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.BatchAnalysisBase,
):  # Class
    BatchAnalyzer: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.BatchAnalyzer
    )  # readonly
    BatchAttributes: BatchAttributes  # readonly
    BatchID: int  # readonly
    BracketingType: BracketingType
    DataSet: BatchDataSet  # readonly
    SampleCount: int  # readonly

    def GetCalibrationReferenceSample(
        self,
        referringSample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample: ...
    def ValidateBatchMethod(self) -> None: ...
    def _OnBatchLoaded(self, dataSet: QuantitationDataSet, batchId: int) -> None: ...
    def RemoveCalibration(
        self, compoundIds: List[int], levelNames: List[str], levelTypes: List[str]
    ) -> None: ...
    def GetCompoundReferenceSet(
        self,
        targetSample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample,
        compoundId: int,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound]: ...
    def GetSample(
        self, sampleId: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample: ...
    def Quantitate(self) -> None: ...
    def GetDependentSamples(
        self,
        calSample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CalibrationSample,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample]: ...
    @overload
    @staticmethod
    def IsSampleSkipped(rowId: RowIdBase) -> bool: ...
    @overload
    @staticmethod
    def IsSampleSkipped(sampleId: int) -> bool: ...
    @overload
    def GetCompounds(
        self,
        compoundRows: System.Collections.Generic.List[
            QuantitationDataSet.TargetCompoundRow
        ],
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    @overload
    def GetCompounds(
        self, sampleType: SampleType
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    @overload
    def GetCompounds(
        self, sampleTypes: List[SampleType]
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    @overload
    def GetCompounds(
        self, sampleType: SampleType, compoundType: CompoundType
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    def GetCalibrationSamples(
        self,
        targetSample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CalibrationSample
    ]: ...
    def GetISTDCompounds(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    def GetTargetCompounds(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    def PrepareToEditMethodWithSample(self, sampleId: int) -> None: ...
    def Integrate(self) -> None: ...
    def GetMatrixCompounds(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    @overload
    def GetNonISTDCompounds(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    @overload
    def GetNonISTDCompounds(
        self, sampleType: SampleType
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    @overload
    def GetNonISTDCompounds(
        self, sampleTypes: List[SampleType]
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    @overload
    def GetSamples(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample
    ]: ...
    @overload
    def GetSamples(
        self, sampleType: SampleType
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample
    ]: ...
    @overload
    def GetSamples(
        self, sampleTypes: List[SampleType]
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample
    ]: ...
    def Analyze(self) -> None: ...
    @overload
    def ClearCalibration(self) -> None: ...
    @overload
    def ClearCalibration(
        self, compoundIds: List[int], levleNames: List[str], levelTypes: List[str]
    ) -> None: ...
    def _OnBatchAnalyzed(self, dataSet: QuantitationDataSet, batchId: int) -> None: ...
    @overload
    def Calibrate(self, average: bool) -> None: ...
    @overload
    def Calibrate(
        self,
        compoundIds: List[int],
        levelConcentrations: List[Optional[float]],
        calSampleIds: List[int],
        average: bool,
    ) -> None: ...
    def CancelBatchProcessing(self) -> None: ...
    def GetCalibrationReferenceCompound(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound: ...
    @overload
    def GetCompoundsExceptFromSampleTypes(
        self, excludedSampleTypes: List[SampleType]
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    @overload
    def GetCompoundsExceptFromSampleTypes(
        self, compoundType: CompoundType, excludedSampleTypes: List[SampleType]
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    def GetAllCompounds(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    @staticmethod
    def EnsureOpenLibraries(
        compliance: ICompliance, batchAttributes: BatchAttributes
    ) -> None: ...
    def CheckSampleTypeForAnalysis(self, sampleId: int) -> None: ...
    def ClearResults(self) -> None: ...
    def _OnBatchAnalysisStarting(
        self, dataSet: QuantitationDataSet, batchId: int
    ) -> None: ...
    def GetSamplesExceptForTypes(
        self, excludedSampleTypes: List[SampleType]
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample
    ]: ...

    BatchAnalyzed: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.BatchAnalyzedEventHandler
    )  # Event
    CompoundListChanged: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundListChangedEventHandler
    )  # Event
    OptimizedBatchAnalysisCompleted: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.OptimizedBatchAnalysisCompletedEventHandler
    )  # Event
    OptimizedBatchAnalysisStarting: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.OptimizedBatchAnalysisStartingEventHandler
    )  # Event
    SampleDeleted: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.SampleDeletedEventHandler
    )  # Event
    SampleRowSkipped: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.SampleRowSkippedEventHandler
    )  # Event

class BatchAnalysisBase(System.IDisposable):  # Class
    DataSet: BatchDataSet  # readonly
    TraceString: str  # readonly

    def IsDirty(self) -> bool: ...
    def Dispose(self) -> None: ...

class BatchAnalysisContext:  # Class
    CurrentBatch: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Batch
    )  # static # readonly

    @staticmethod
    def GetActiveBatch() -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Batch
    ): ...
    @staticmethod
    def CloseBatch() -> None: ...
    @staticmethod
    def GetQualifier(
        rowId: TargetQualifierRowId,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.QualifierIon: ...
    @staticmethod
    def GetCompound(
        rowId: TargetCompoundRowId,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound: ...
    @staticmethod
    def OpenBatch(
        commandContext: AppCommandContext, batchId: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Batch: ...
    @staticmethod
    def ValidateActiveBatch(batchId: int) -> None: ...
    @staticmethod
    def ValidateRowId(rowId: RowIdBase) -> None: ...

class BatchAnalyzedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, args: System.EventArgs) -> None: ...

class BatchAnalyzer(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.IQuantDataSetLookup
):  # Class
    def __init__(
        self, batch: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Batch
    ) -> None: ...

    SampleAnalyzers: System.Collections.Generic.SortedList[
        int, Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.SampleAnalyzer
    ]  # readonly

    def GetCompoundReferenceSet(
        self,
        targetSampleAnalyzer: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.SampleAnalyzer,
        compoundID: int,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundAnalyzer
    ]: ...
    def GetDataSet(self, sampleID: int) -> IQuantDataSet: ...
    def Quantitate(self, parallel: bool) -> None: ...
    def GetCalibrationSamples(
        self,
        targetSample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.SampleAnalyzer
    ]: ...
    def Analyze(self, parallel: bool) -> None: ...
    @overload
    def GetOptimizedCompoundRow(
        self, sampleID: int, compoundID: int
    ) -> ITargetCompoundRow: ...
    @overload
    def GetOptimizedCompoundRow(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound,
    ) -> ITargetCompoundRow: ...
    @overload
    def GetSampleRow(self, sampleID: int) -> IBatchRow: ...
    @overload
    def GetSampleRow(
        self, sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample
    ) -> IBatchRow: ...
    def Integrate(self, parallel: bool) -> None: ...
    def Calibrate(self, parallel: bool) -> None: ...
    def GetCalibrationReferenceCompoundAnalyzer(
        self,
        compoundAnalyzer: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundAnalyzer,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundAnalyzer
    ): ...

class BatchAnalyzer:  # Class
    def __init__(self) -> None: ...

class CalibrationChangedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, args: System.EventArgs) -> None: ...

class CalibrationSample(
    IScriptableSample,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        batch: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Batch,
        sampleId: int,
    ) -> None: ...

    LevelName: str  # readonly

    CalibrationChanged: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CalibrationChangedEventHandler
    )  # Event

class ChromPeakDeconvolution:  # Class
    @overload
    def __init__(self, dataAccess: IMSDataAccess) -> None: ...
    @overload
    def __init__(
        self, dataAccess: Agilent.MassSpectrometry.DataAnalysis.IDataAccess
    ) -> None: ...

    RTRange: Agilent.MassSpectrometry.DataAnalysis.IRange  # readonly

    @staticmethod
    def RescaleComponentSpectrum(
        targetComponent: Agilent.MassSpectrometry.DataAnalysis.Component,
        peakAveragedSpectrum: Agilent.MassSpectrometry.DataAnalysis.ISpectrum,
        targetPurity: float,
    ) -> None: ...
    @overload
    def ComputePeakPurity(
        self,
        peak: Agilent.MassSpectrometry.DataAnalysis.IChromPeak,
        compoundRow: ITargetCompoundRow,
        spectralComponents: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Component
        ],
        targetComponent: Agilent.MassSpectrometry.DataAnalysis.Component,
    ) -> float: ...
    @overload
    def ComputePeakPurity(
        self,
        peak: Agilent.MassSpectrometry.DataAnalysis.IChromPeak,
        spectralComponents: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Component
        ],
        targetComponent: Agilent.MassSpectrometry.DataAnalysis.Component,
    ) -> float: ...
    @overload
    def GetSpectralComponents(
        self,
        peak: Agilent.MassSpectrometry.DataAnalysis.IChromPeak,
        compoundRow: ITargetCompoundRow,
    ) -> Dict[
        Agilent.MassSpectrometry.DataAnalysis.Component,
        System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Component
        ],
    ]: ...
    @overload
    def GetSpectralComponents(
        self,
        peak: Agilent.MassSpectrometry.DataAnalysis.IChromPeak,
        mzRange: Agilent.MassSpectrometry.DataAnalysis.IRange,
    ) -> Dict[
        Agilent.MassSpectrometry.DataAnalysis.Component,
        System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Component
        ],
    ]: ...
    @overload
    def GetSpectralComponents(
        self,
        peak: Agilent.MassSpectrometry.DataAnalysis.IChromPeak,
        compoundRow: ITargetCompoundRow,
        deconvolutionMethods: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.DeconvolutionMethodDataTable,
    ) -> Dict[
        Agilent.MassSpectrometry.DataAnalysis.Component,
        System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Component
        ],
    ]: ...
    @overload
    def GetSpectralComponents(
        self,
        peak: Agilent.MassSpectrometry.DataAnalysis.IChromPeak,
        mzRange: Agilent.MassSpectrometry.DataAnalysis.IRange,
        deconvolutionMethods: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.DeconvolutionMethodDataTable,
    ) -> Dict[
        Agilent.MassSpectrometry.DataAnalysis.Component,
        System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Component
        ],
    ]: ...

class Compound(
    IScriptableCompound,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.BatchAnalysisBase,
):  # Class
    def __init__(
        self,
        sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample,
        compoundId: int,
    ) -> None: ...

    Calibration: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundCalibration
    )  # readonly
    CompoundID: int  # readonly
    CompoundRow: QuantitationDataSet.TargetCompoundRow  # readonly
    CompoundSpectrum: Agilent.MassSpectrometry.DataAnalysis.ISpectrum  # readonly
    CompoundSpectrumForReferenceLibraryMatch: (
        Agilent.MassSpectrometry.DataAnalysis.ISpectrum
    )  # readonly
    CompoundType: CompoundType  # readonly
    DataSet: BatchDataSet  # readonly
    Dependents: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]  # readonly
    HasDependents: bool  # readonly
    HasTimeReference: bool  # readonly
    IsAreaCorrectionEnabled: bool  # readonly
    IsCompoundOrDependentsAreaCorrected: bool  # readonly
    IsISTD: bool  # readonly
    IsManuallyIntegrated: bool  # readonly
    Qualifiers: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.QualifierIon
    ]  # readonly
    Quantifier: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.QuantifierIon
    )  # readonly
    Sample: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample
    )  # readonly
    SpectrumExtractionOverride: SpectrumExtractionOverride  # readonly

    def Quantitate(self) -> None: ...
    def _OnCompoundCalibrationStarting(
        self, compoundRow: QuantitationDataSet.TargetCompoundRow, average: bool
    ) -> None: ...
    def _OnCompoundQuantitated(
        self, compoundRow: QuantitationDataSet.TargetCompoundRow
    ) -> None: ...
    def GetAggregateCompound(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    def _IgnoreQuantitationErrors(
        self,
        compoundRow: QuantitationDataSet.TargetCompoundRow,
        manuallyIntegrated: bool,
    ) -> bool: ...
    def GetQualifier(
        self, qualifierId: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.QualifierIon: ...
    def GetGroupCompounds(
        self, groupName: str
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    def _OnCompoundIntegrationStarting(
        self, compoundRow: QuantitationDataSet.TargetCompoundRow
    ) -> None: ...
    def _OnCompoundQuantitationFailed(
        self, compoundRow: QuantitationDataSet.TargetCompoundRow
    ) -> None: ...
    def HasISTD(self) -> bool: ...
    def Integrate(self, startFromScratch: bool) -> None: ...
    def _OnCompoundCalibrated(
        self, compoundRow: QuantitationDataSet.TargetCompoundRow, average: bool
    ) -> None: ...
    def Calibrate(
        self,
        calSampleIds: List[int],
        levelConcentration: Optional[float],
        average: bool,
    ) -> None: ...
    def _IgnorePeakNotFoundException(
        self,
        compoundRow: QuantitationDataSet.TargetCompoundRow,
        e: System.ApplicationException,
        manuallyIntegrated: bool,
    ) -> bool: ...
    def _OnCompoundIntegrated(
        self, compoundRow: QuantitationDataSet.TargetCompoundRow
    ) -> None: ...
    def GetISTD(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound: ...
    def _OnCompoundQuantitationStarting(
        self, compoundRow: QuantitationDataSet.TargetCompoundRow
    ) -> None: ...

    CompoundIntegrated: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundQuantitationEventHandler
    )  # Event
    CompoundQuantitated: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundQuantitationEventHandler
    )  # Event
    CompoundQuantitationFailed: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundQuantitationEventHandler
    )  # Event
    OptimizedCompoundQuantitated: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.OptimizedCompoundEventHandler
    )  # Event
    QuantitationChanged: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundQuantitationEventHandler
    )  # Event

class CompoundAnalyzer:  # Class
    Calibrator: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundCalibrator
    )  # readonly
    CompoundID: int  # readonly
    CompoundSpectrumForReferenceLibraryMatch: (
        Agilent.MassSpectrometry.DataAnalysis.ISpectrum
    )  # readonly
    ISTDCompoundAnalyzer: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundAnalyzer
    )  # readonly
    IsISTD: bool  # readonly

class CompoundCalibration(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.BatchAnalysisBase,
):  # Class
    CalCurveFit: CalibrationCurveFit  # readonly
    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    )  # readonly
    DataSet: BatchDataSet  # readonly

    def GetCalRowsByLevel(
        self, levelNames: System.Collections.Generic.List[str]
    ) -> Dict[str, System.Collections.Generic.List[ICalibrationRow]]: ...
    def GetISTDConcentration(self) -> float: ...
    @staticmethod
    def GetResponseStatisticsByLevel(
        rowId: TargetCompoundRowId,
    ) -> List[CalibrationLevel]: ...
    @staticmethod
    def ApplyIsotopicDilutionCorrection(
        rowId: TargetCompoundRowId, relResponses: List[float]
    ) -> None: ...

class CompoundCalibrator:  # Class
    def __init__(
        self,
        compoundAnalyzer: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundAnalyzer,
    ) -> None: ...
    def GetISTDConcentration(self) -> float: ...

class CompoundListChangedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, args: System.EventArgs) -> None: ...

class CompoundQuantitationEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, args: System.EventArgs) -> None: ...

class IQuantDataSetLookup(object):  # Interface
    @overload
    def GetSampleRow(self, sampleID: int) -> IBatchRow: ...
    @overload
    def GetSampleRow(
        self, sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample
    ) -> IBatchRow: ...
    def GetDataSet(self, sampleID: int) -> IQuantDataSet: ...
    @overload
    def GetOptimizedCompoundRow(
        self, sampleID: int, compoundID: int
    ) -> ITargetCompoundRow: ...
    @overload
    def GetOptimizedCompoundRow(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound,
    ) -> ITargetCompoundRow: ...

class IntegratorPSetCache:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, nSamples: int, nCompounds: int, nQualifiers: int) -> None: ...
    def AddTimeSegments(self, sampleID: int, timeSegments: List[float]) -> None: ...

class ManualIntegrationEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, args: System.EventArgs) -> None: ...

class ManualIntegrationResult:  # Class
    ResponseRatioOriginal: float  # readonly

class MeasuredIon(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.BatchAnalysisBase,
):  # Class
    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    )  # readonly
    DataSet: BatchDataSet  # readonly
    IntegrationErrorMessage: str  # readonly
    ManuallyIntegrated: bool
    NoiseRegions: Agilent.MassSpectrometry.DataAnalysis.RangeCollection  # readonly
    Response: float  # readonly
    SpectralComponents: List[
        Agilent.MassSpectrometry.DataAnalysis.Component
    ]  # readonly
    TargetComponent: Agilent.MassSpectrometry.DataAnalysis.Component  # readonly
    TargetComponentArea: Optional[float]  # readonly
    UserSelectedPeak: Agilent.MassSpectrometry.DataAnalysis.IChromPeak  # readonly
    UserSelectedPeakIndex: int  # readonly

    @staticmethod
    def CalcDeconvolutedValues(
        component: Agilent.MassSpectrometry.DataAnalysis.Component,
        area: Optional[float],
        height: Optional[float],
    ) -> None: ...
    @overload
    def FindSpectralComponents(self) -> None: ...
    @overload
    def FindSpectralComponents(
        self, peakRow: QuantitationDataSet.PeakRow
    ) -> Optional[float]: ...
    def GetPeaksInRange(
        self, xMin: float, xMax: float
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.IChromPeak]: ...
    def FindPeaks(self) -> Agilent.MassSpectrometry.DataAnalysis.IChromPeakList: ...
    def ClearManualIntegration(self) -> None: ...
    def SnapBaseline(self, xStart: float, xEnd: float) -> None: ...
    def ManualIntegrate(
        self, xStart: float, yStart: float, xEnd: float, yEnd: float
    ) -> None: ...

    ManualIntegrationChanged: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.ManualIntegrationEventHandler
    )  # Event
    ManualIntegrationCleared: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.ManualIntegrationEventHandler
    )  # Event

class OptimizedBatchAnalysisCompletedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, args: System.EventArgs) -> None: ...

class OptimizedBatchAnalysisStartingEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.OptimizedBatchEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self,
        sender: Any,
        args: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.OptimizedBatchEventArgs,
    ) -> None: ...

class OptimizedBatchEventArgs:  # Class
    def __init__(
        self, childDataSets: System.Collections.Generic.List[IQuantDataSet]
    ) -> None: ...

    ChildDataSets: System.Collections.Generic.List[IQuantDataSet]  # readonly

class OptimizedCompoundEventArgs:  # Class
    CompoundRow: ITargetCompoundRow  # readonly

class OptimizedCompoundEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.OptimizedCompoundEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self,
        sender: Any,
        args: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.OptimizedCompoundEventArgs,
    ) -> None: ...

class ProcessingState(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Dirty: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.ProcessingState
    ) = ...  # static # readonly
    Initialized: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.ProcessingState
    ) = ...  # static # readonly
    Processed: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.ProcessingState
    ) = ...  # static # readonly

class Qualifier(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.TargetIon
):  # Class
    ...

class QualifierIon(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.MeasuredIon,
    IScriptableQualifierIon,
):  # Class
    def __init__(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound,
        qualifierId: int,
    ) -> None: ...

    Chromatogram: Agilent.MassSpectrometry.DataAnalysis.IChromatogram  # readonly
    PeakQualifierRow: QuantitationDataSet.PeakQualifierRow  # readonly
    QualifierID: int  # readonly
    Response: float  # readonly
    TargetQualifierRow: QuantitationDataSet.TargetQualifierRow  # readonly

    def MergePeak(self, withLeft: bool, snap: bool) -> None: ...
    @staticmethod
    def IsValidManuallyIntegratedPeak(
        peakQualifierRow: QuantitationDataSet.PeakQualifierRow,
    ) -> bool: ...
    def ZeroOutPeak(self) -> None: ...
    def _OnManualIntegrationCompleted(
        self,
        qualifierRow: QuantitationDataSet.TargetQualifierRow,
        peakList: Agilent.MassSpectrometry.DataAnalysis.IPeakList,
    ) -> None: ...
    def SplitPeak(self, isLeftPrimary: bool, snap: bool) -> None: ...
    def _OnManualIntegrationStarting(
        self,
        qualifierRow: QuantitationDataSet.TargetQualifierRow,
        peakList: Agilent.MassSpectrometry.DataAnalysis.IPeakList,
        xStart: float,
        xEnd: float,
        yStart: float,
        yEnd: float,
    ) -> None: ...
    def DropBaseline(self, y: float) -> None: ...
    def _OnFindPeaksCompleted(
        self,
        qualifierRow: QuantitationDataSet.TargetQualifierRow,
        peakList: Agilent.MassSpectrometry.DataAnalysis.IPeakList,
    ) -> None: ...
    def SelectPeak(self, peakId: int) -> None: ...
    def _OnFindPeaksStarting(
        self, qualifierRow: QuantitationDataSet.TargetQualifierRow
    ) -> None: ...

class QuantEngine(System.IDisposable):  # Class
    def StartSet(self, sortBySignal: bool) -> None: ...
    def Dispose(self) -> None: ...
    def EndSet(
        self, sortBySignal: bool, correlationWindowInMilliseconds: int
    ) -> None: ...
    def AddPeaks(
        self, peakList: Agilent.MassSpectrometry.DataAnalysis.IPeakList, signalId: int
    ) -> None: ...

class Quantifier(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.TargetIon
):  # Class
    @staticmethod
    def CalcDeconvolutedValues(
        component: Agilent.MassSpectrometry.DataAnalysis.Component,
        area: Optional[float],
        height: Optional[float],
    ) -> None: ...
    def FindSpectralComponents(self) -> None: ...

class QuantifierIon(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.MeasuredIon,
    System.IDisposable,
    IScriptableQuantifierIon,
    ICustomExpressions,
):  # Class
    def __init__(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound,
    ) -> None: ...

    CONFIG_XML_FILE: str = ...  # static # readonly

    Chromatogram: Agilent.MassSpectrometry.DataAnalysis.IChromatogram  # readonly
    PeakRow: QuantitationDataSet.PeakRow  # readonly
    Response: float  # readonly
    UncorrectedResponse: float  # readonly

    def MergePeak(self, withLeft: bool, snap: bool) -> None: ...
    @overload
    def ZeroOutPeak(self) -> None: ...
    @overload
    def ZeroOutPeak(self, peakId: int) -> None: ...
    def _OnManualIntegrationCompleted(
        self,
        compoundRow: QuantitationDataSet.TargetCompoundRow,
        peakList: Agilent.MassSpectrometry.DataAnalysis.IPeakList,
    ) -> None: ...
    def _UpdateFinalConcentration(
        self, peakRow: QuantitationDataSet.PeakRow
    ) -> None: ...
    def SplitPeak(self, isLeftPrimary: bool, snap: bool) -> None: ...
    def _OnManualIntegrationStarting(
        self,
        compoundRow: QuantitationDataSet.TargetCompoundRow,
        peakList: Agilent.MassSpectrometry.DataAnalysis.IPeakList,
        xStart: float,
        xEnd: float,
        yStart: float,
        yEnd: float,
    ) -> None: ...
    def _UpdateAccuracy(self, peakRow: QuantitationDataSet.PeakRow) -> None: ...
    def DropBaseline(self, y: float) -> None: ...
    def _OnFindPeaksCompleted(
        self,
        compoundRow: QuantitationDataSet.TargetCompoundRow,
        peakList: Agilent.MassSpectrometry.DataAnalysis.IPeakList,
    ) -> None: ...
    def SelectPeak(self, peakId: int) -> None: ...
    def _OnFindPeaksStarting(
        self, compoundRow: QuantitationDataSet.TargetCompoundRow
    ) -> None: ...

class QuantitationEngine:  # Class
    def Quantitate(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound,
        bComputeConcentration: bool,
        clearManualIntegration: bool,
    ) -> None: ...
    def IntegrateCompound(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound,
    ) -> None: ...

class Sample(
    IScriptableSample,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.BatchAnalysisBase,
):  # Class
    def __init__(
        self,
        batch: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Batch,
        sampleId: int,
    ) -> None: ...

    Batch: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Batch  # readonly
    CalibrationSamples: Dict[
        str,
        System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CalibrationSample
        ],
    ]  # readonly
    DataAccess: IMSDataAccess  # readonly
    DataSet: BatchDataSet  # readonly
    Deconvolution: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.ChromPeakDeconvolution
    )  # readonly
    QuantitationEngine: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.QuantitationEngine
    )  # readonly
    SampleID: int  # readonly
    SampleRow: QuantitationDataSet.BatchRow  # readonly
    SampleType: SampleType  # readonly
    TraceString: str  # readonly

    def Quantitate(self) -> None: ...
    def _OnSampleIntegrationStarting(
        self, sampleRow: QuantitationDataSet.BatchRow
    ) -> None: ...
    def GetISTDCompounds(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    def GetCalibrationSamples(
        self, levelName: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CalibrationSample
    ]: ...
    def GetTICResponse(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound,
        rt: float,
    ) -> float: ...
    @staticmethod
    def SortByDateTime(
        samples: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Sample
        ],
    ) -> None: ...
    def ContainsCompound(self, compoundId: int) -> bool: ...
    def _OnSampleCalibrated(
        self, sampleRow: QuantitationDataSet.BatchRow, average: bool
    ) -> None: ...
    @overload
    def GetCompounds(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    @overload
    def GetCompounds(
        self, compoundType: CompoundType
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    def GetCompound(
        self, compoundId: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound: ...
    def _OnSampleCalibrationStarting(
        self, sampleRow: QuantitationDataSet.BatchRow, average: bool
    ) -> None: ...
    def GetNonISTDCompounds(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    def _OnSampleIntegrated(self, sampleRow: QuantitationDataSet.BatchRow) -> None: ...
    def Integrate(self, clearResults: bool) -> None: ...
    def _OnSampleQuantitated(self, sampleRow: QuantitationDataSet.BatchRow) -> None: ...
    def Calibrate(self, average: bool) -> None: ...
    def GetTargetCompounds(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound
    ]: ...
    def FindCompound(
        self, compoundId: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.Compound: ...
    def _OnSampleQuantitationStarting(
        self, sampleRow: QuantitationDataSet.BatchRow
    ) -> None: ...

class SampleAnalyzer:  # Class
    SampleDataSet: OptimizedQuantDataSet  # readonly

    def GetTICResponse(
        self,
        cmpdAnalyzer: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Analysis.CompoundAnalyzer,
        rt: float,
    ) -> float: ...

class SampleDeletedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, args: System.EventArgs) -> None: ...

class SampleRowSkippedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        args: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, args: System.EventArgs) -> None: ...

class TargetIon:  # Class
    ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import IGraphics, Pane, ZoomInfo

# Stubs for namespace: Agilent.MassSpectrometry.GUI.Plot.Events

class DrawPaneEventArgs(System.EventArgs):  # Class
    @overload
    def __init__(
        self,
        pane: Pane,
        paneRectangle: System.Drawing.Rectangle,
        g: System.Drawing.Graphics,
    ) -> None: ...
    @overload
    def __init__(
        self, pane: Pane, paneRectangle: System.Drawing.Rectangle, g: IGraphics
    ) -> None: ...

    Graphics: System.Drawing.Graphics  # readonly
    IGraphics: IGraphics  # readonly
    Pane: Pane  # readonly
    PaneRectangle: System.Drawing.Rectangle  # readonly

class PaneEventArgs(System.EventArgs):  # Class
    def __init__(self, pane: Pane) -> None: ...

    Pane: Pane  # readonly

class ZoomHistoryEventArgs(System.EventArgs):  # Class
    def __init__(self, zoomInfoOld: ZoomInfo, zoomInfoNew: ZoomInfo) -> None: ...

    NewZoomInfo: ZoomInfo  # readonly
    OldZoomInfo: ZoomInfo  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    MFE,
    MFE2005,
    MS,
    AGaugeApp,
    Agilent,
    AgilentErrorReporter,
    AGTPICSYSSERVICESLib,
    AGTPICWORKLISTLib,
    BasicTypes,
    Biochemistry,
    CommonAlgorithms,
    ComponentAce,
    CompositionCalculatorEngine,
    CompositionDB,
    CompoundFilters,
    CorrelationNormalizationEngine3,
    DataFitX3,
    Definitions,
    Dennany,
    GenieIntegrator,
    Infragistics,
    Ionic,
    IronPython,
    IronRuby,
    IsotopePatternCalculator,
    IWshRuntimeLibrary,
    Mathematics,
    Mfe,
    MhdFile,
    Microsoft,
    OpenLABTranslator,
    Org,
    PdfSharp,
    PerCederberg,
    PersistanceFiles,
    Storer,
    System,
    Util,
    XamlGeneratedNamespace,
    Xceed,
    com,
    iTextSharp,
    log4net,
    vbAccelerator,
)

# Stubs for namespace: <global>

class CompressWrapper(System.IDisposable):  # Class
    @overload
    def __init__(self, deviceType: int) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def SetDeviceType(self, deviceType: int) -> None: ...
    def Dispose(self) -> None: ...
    @overload
    def DecompressData(
        self,
        pRecordInfo: ScanRecordInfo,
        CompressionType: int,
        inOutCompressedBuff: List[int],
    ) -> None: ...
    @overload
    def DecompressData(
        self,
        pRecordInfo: ScanRecordInfo,
        CompressionType: int,
        inCompressedBuff: List[int],
        outDecompressedBuff: List[int],
    ) -> None: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class DotfuscatorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, a: str, c: int) -> None: ...

    A: str  # readonly
    C: int  # readonly

    def a(self) -> str: ...
    def c(self) -> int: ...

class PeakAdapter(System.IDisposable):  # Class
    def __init__(
        self,
        startIndex: int,
        apexIndex: int,
        endIndex: int,
        startY: float,
        apexY: float,
        endY: float,
        height: float,
        centerX: float,
        width: float,
        area: float,
        suspect: int,
    ) -> None: ...

    ApexIndex: int
    ApexY: float
    Area: float
    CenterX: float
    EndIndex: int
    EndY: float
    Height: float
    StartIndex: int
    StartY: float
    Suspect: int
    Width: float

    def Dispose(self) -> None: ...

class PeakFinderAdapter(System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def SetParameters(self, heightRejectAbs: float, saturationLevel: float) -> None: ...
    def Dispose(self) -> None: ...
    def FindPeaks(self, spectrum: List[float]) -> List[PeakAdapter]: ...

class ScanRecordInfo(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    m_ActualsOffset: int
    m_BpcAbundance: float
    m_BpcMZ: float
    m_CollisionEnergy: float
    m_DD_ParamMz_1: float
    m_DD_ScanID: int
    m_Fragmentor: float
    m_IonMode: int
    m_IonPolarity: int
    m_MSLevel: int
    m_MSScanType: int
    m_MZOfInterest: float
    m_MassCalOffset: int
    m_MethodID: int
    m_RetentionTime: float
    m_SamplingPeriod: float
    m_ScanID: int
    m_TIC: float
    m_TimeSegmentID: int
    m_pSpectrumParams: SpecParams

    def Dispose(self) -> None: ...
    def GetUnmanagedScanRecordInfo(self, scanrec: System.IntPtr) -> bool: ...

class SharedWorklistStrings:  # Class
    def __init__(self) -> None: ...

    AcqMethod: str = ...  # static # readonly
    AcqTime: str = ...  # static # readonly
    AutoIncr: str = ...  # static # readonly
    BalanceType: str = ...  # static # readonly
    Barcode: str = ...  # static # readonly
    CalibLevelName: str = ...  # static # readonly
    CombinedReportOutputFile: str = ...  # static # readonly
    DAMethod: str = ...  # static # readonly
    DataFileName: str = ...  # static # readonly
    Description: str = ...  # static # readonly
    DilutionFactor: str = ...  # static # readonly
    EquilibrationTime: str = ...  # static # readonly
    ExpectedBarcode: str = ...  # static # readonly
    ISTDDilution: str = ...  # static # readonly
    InjectionVolume: str = ...  # static # readonly
    InstrumentName: str = ...  # static # readonly
    MethodExecutionType: str = ...  # static # readonly
    MethodNoOverride: str = ...  # static # readonly
    OperatorName: str = ...  # static # readonly
    OverWriteDataFile: str = ...  # static # readonly
    PlateCode: str = ...  # static # readonly
    PlatePosition: str = ...  # static # readonly
    RackCode: str = ...  # static # readonly
    RackPosition: str = ...  # static # readonly
    ReadyTimeOut: str = ...  # static # readonly
    Reserved1: str = ...  # static # readonly
    Reserved2: str = ...  # static # readonly
    Reserved3: str = ...  # static # readonly
    Reserved4: str = ...  # static # readonly
    Reserved5: str = ...  # static # readonly
    Reserved6: str = ...  # static # readonly
    RunAcqAndDAMethod: str = ...  # static # readonly
    RunAcqOnlyMethod: str = ...  # static # readonly
    RunCompletedFlag: str = ...  # static # readonly
    RunDAOnlyMethod: str = ...  # static # readonly
    RunType: str = ...  # static # readonly
    RuntypeExternalRun: str = ...  # static # readonly
    RuntypeLCOnlyRun: str = ...  # static # readonly
    RuntypeManualRun: str = ...  # static # readonly
    RuntypeStandardRun: str = ...  # static # readonly
    SampleAmount: str = ...  # static # readonly
    SampleID: str = ...  # static # readonly
    SampleLockedRunMode: str = ...  # static # readonly
    SampleName: str = ...  # static # readonly
    SamplePosition: str = ...  # static # readonly
    SampleType: str = ...  # static # readonly
    SamplingDateTime: str = ...  # static # readonly
    TotalSampleAmount: str = ...  # static # readonly
    UserDefined: str = ...  # static # readonly
    UserName: str = ...  # static # readonly
    WeightPerVolume: str = ...  # static # readonly
    strBlank: str = ...  # static # readonly
    strCalibration: str = ...  # static # readonly
    strConCal: str = ...  # static # readonly
    strDoubleBlank: str = ...  # static # readonly
    strMatrix: str = ...  # static # readonly
    strMatrixBlank: str = ...  # static # readonly
    strMatrixDup: str = ...  # static # readonly
    strQC: str = ...  # static # readonly
    strResponseCheck: str = ...  # static # readonly
    strSample: str = ...  # static # readonly
    strTuneCheck: str = ...  # static # readonly

class SharedWorklistStrings:  # Class
    def __init__(self) -> None: ...

    AcqMethod: str = ...  # static # readonly
    AcqTime: str = ...  # static # readonly
    BalanceType: str = ...  # static # readonly
    Barcode: str = ...  # static # readonly
    CalibLevelName: str = ...  # static # readonly
    CombinedReportOutputFile: str = ...  # static # readonly
    DAMethod: str = ...  # static # readonly
    DataFileName: str = ...  # static # readonly
    Description: str = ...  # static # readonly
    DilutionFactor: str = ...  # static # readonly
    EquilibrationTime: str = ...  # static # readonly
    ExpectedBarcode: str = ...  # static # readonly
    ISTDDilution: str = ...  # static # readonly
    InjectionVolume: str = ...  # static # readonly
    InstrumentName: str = ...  # static # readonly
    MethodExecutionType: str = ...  # static # readonly
    OperatorName: str = ...  # static # readonly
    PlateCode: str = ...  # static # readonly
    PlatePosition: str = ...  # static # readonly
    RackCode: str = ...  # static # readonly
    RackPosition: str = ...  # static # readonly
    Reserved1: str = ...  # static # readonly
    Reserved2: str = ...  # static # readonly
    Reserved3: str = ...  # static # readonly
    Reserved4: str = ...  # static # readonly
    Reserved5: str = ...  # static # readonly
    Reserved6: str = ...  # static # readonly
    RunCompletedFlag: str = ...  # static # readonly
    SampleAmount: str = ...  # static # readonly
    SampleID: str = ...  # static # readonly
    SampleLockedRunMode: str = ...  # static # readonly
    SampleName: str = ...  # static # readonly
    SamplePosition: str = ...  # static # readonly
    SampleType: str = ...  # static # readonly
    SamplingDateTime: str = ...  # static # readonly
    TotalSampleAmount: str = ...  # static # readonly
    UserDefined: str = ...  # static # readonly
    UserName: str = ...  # static # readonly
    WeightPerVolume: str = ...  # static # readonly
    strBlank: str = ...  # static # readonly
    strCalibration: str = ...  # static # readonly
    strConCal: str = ...  # static # readonly
    strDoubleBlank: str = ...  # static # readonly
    strMatrix: str = ...  # static # readonly
    strMatrixBlank: str = ...  # static # readonly
    strMatrixDup: str = ...  # static # readonly
    strQC: str = ...  # static # readonly
    strResponseCheck: str = ...  # static # readonly
    strSample: str = ...  # static # readonly
    strTuneCheck: str = ...  # static # readonly

class SpecParams(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    m_ByteCount: int
    m_MinX: float
    m_Offset: int
    m_PointCount: int
    m_UncompressedByteCount: int

    def Dispose(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Definitions import (
    ApplicationCommand,
    ApplicationMenu2010Item,
    Button,
    CheckButton,
    ComboBox,
    ContextMenu,
    GalleryItem,
    Group,
    Label,
    Menu,
    Separator,
    TabItem,
    TextBox,
    ToolBase,
)
from .ToolManager import IContextMenuToolState, IToolbar, IToolManager

# Stubs for namespace: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState

class ApplicationCommandState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
):  # Class
    def __init__(
        self, toolManager: IToolManager, definition: ApplicationCommand
    ) -> None: ...

    Enabled: bool
    _Control: System.Windows.Controls.Control  # readonly

    def CanExecute(
        self, sender: Any, e: System.Windows.Input.CanExecuteRoutedEventArgs
    ) -> None: ...
    def Execute(
        self, sender: Any, e: System.Windows.Input.ExecutedRoutedEventArgs
    ) -> None: ...

class ApplicationMenu2010ToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: ApplicationMenu2010Item,
        item: Infragistics.Windows.Ribbon.ApplicationMenu2010Item,
    ) -> None: ...

    Definition: ApplicationMenu2010Item  # readonly
    DisplayStyle: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    )
    DisplayText: str
    Enabled: bool
    _Control: System.Windows.Controls.Control  # readonly

    def RemoveSelf(self) -> None: ...

class ButtonBaseToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: Button,
        button: System.Windows.Controls.Primitives.ButtonBase,
    ) -> None: ...

    DisplayStyle: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    )
    DisplayText: str
    Enabled: bool
    _Control: System.Windows.Controls.Control  # readonly

    def RemoveSelf(self) -> None: ...

class ButtonToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: Button,
        button: Infragistics.Windows.Ribbon.ButtonTool,
    ) -> None: ...

    Definition: Button  # readonly
    DisplayStyle: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    )
    DisplayText: str
    Enabled: bool
    Image: str
    _Control: System.Windows.Controls.Control  # readonly

    def RemoveSelf(self) -> None: ...

class CheckButtonToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ICheckToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: CheckButton,
        toggleButton: Infragistics.Windows.Ribbon.ToggleButtonTool,
    ) -> None: ...

    Checked: bool
    DisplayText: str
    Enabled: bool
    Image: str
    _Control: System.Windows.Controls.Control  # readonly

    def RemoveSelf(self) -> None: ...

class ComboBoxToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IComboBoxToolState,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: ComboBox,
        comboBox: System.Windows.Controls.ComboBox,
    ) -> None: ...

    DisplayStyle: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    )
    DisplayText: str
    Enabled: bool
    IsComboBox: bool  # readonly
    IsDroppedDown: bool  # readonly
    ItemCount: int  # readonly
    SelectedIndex: int
    SelectedItem: Any
    _Control: System.Windows.Controls.Control  # readonly

    def ClearItems(self) -> None: ...
    def BeforeToolDropdown(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        add: bool,
    ) -> None: ...
    def GetItemValue(self, index: int) -> Any: ...
    def IndexOf(self, value_: Any) -> int: ...
    def Remove(self, item: Any) -> None: ...
    def GetItemDisplayText(self, index: int) -> str: ...
    def AddItem(self, item: Any, displayText: str) -> None: ...
    def CloseDropdown(self) -> None: ...
    def RemoveSelf(self) -> None: ...
    def RemoveAt(self, index: int) -> None: ...

class ComboEditorToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IComboBoxToolState,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: ComboBox,
        combo: Infragistics.Windows.Ribbon.ComboEditorTool,
    ) -> None: ...

    Enabled: bool
    IsDroppedDown: bool  # readonly
    ItemCount: int  # readonly
    SelectedIndex: int
    SelectedItem: Any
    _Control: System.Windows.Controls.Control  # readonly

    def ClearItems(self) -> None: ...
    def BeforeToolDropdown(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        add: bool,
    ) -> None: ...
    def GetItemValue(self, index: int) -> Any: ...
    def IndexOf(self, value_: Any) -> int: ...
    def Remove(self, item: Any) -> None: ...
    def GetItemDisplayText(self, index: int) -> str: ...
    def AddItem(self, item: Any, displayText: str) -> None: ...
    def CloseDropdown(self) -> None: ...
    def RemoveAt(self, index: int) -> None: ...

class ContextMenuState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IPopupMenuToolState,
    IContextMenuToolState,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: ContextMenu,
        contextMenu: System.Windows.Controls.ContextMenu,
    ) -> None: ...

    Count: int  # readonly
    Enabled: bool
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    _Control: System.Windows.Controls.Control  # readonly

    def SetContextMenu(self, element: System.Windows.FrameworkElement) -> None: ...
    def Add(self, id: str) -> None: ...
    def ShowPopupMenu(self) -> None: ...
    def BeforeToolDropdown(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        add: bool,
    ) -> None: ...
    def Clear(self) -> None: ...
    def IndexOf(self, id: str) -> int: ...
    def Remove(self, id: str) -> None: ...
    def Exists(self, id: str) -> bool: ...
    def Insert(self, id: str, index: int) -> None: ...
    def InsertSeparator(self, index: int) -> None: ...
    def RemoveAt(self, index: int) -> None: ...

class ExpanderBarGroupState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IExplorerBarGroup,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: Group,
        expander: System.Windows.Controls.Expander,
    ) -> None: ...

    Enabled: bool
    Expanded: bool
    _Control: System.Windows.Controls.Control  # readonly

    def Add(self, id: str) -> None: ...
    def IndexOf(self, id: str) -> int: ...
    def Remove(self, id: str) -> None: ...
    def Exists(self, id: str) -> bool: ...
    def Insert(self, index: int, id: str) -> None: ...

class GalleryItemToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
):  # Class
    def __init__(
        self,
        toolManaer: IToolManager,
        definition: GalleryItem,
        item: Infragistics.Windows.Ribbon.GalleryItem,
    ) -> None: ...

    Enabled: bool
    _Control: System.Windows.Controls.Control  # readonly

class IToolState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
):  # Interface
    Definition: ToolBase  # readonly
    ID: str
    IsEnabled: bool  # readonly
    QueryingCanExecute: bool

    def RemoveSelf(self) -> None: ...
    def RemoveChild(self, id: str) -> None: ...

class LabelToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: Label,
        label: System.Windows.Controls.Label,
    ) -> None: ...

    Enabled: bool
    _Control: System.Windows.Controls.Control  # readonly

    def RemoveSelf(self) -> None: ...

class MenuItemToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ICheckToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IPopupMenuToolState,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: ToolBase,
        menuItem: System.Windows.Controls.MenuItem,
    ) -> None: ...

    Checked: bool
    Count: int  # readonly
    DisplayStyle: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    )
    Enabled: bool
    IsPopup: bool
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    _Control: System.Windows.Controls.Control  # readonly

    def Add(self, id: str) -> None: ...
    def ShowPopupMenu(self) -> None: ...
    def BeforeToolDropdown(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        add: bool,
    ) -> None: ...
    def Clear(self) -> None: ...
    def IndexOf(self, id: str) -> int: ...
    def Remove(self, id: str) -> None: ...
    def Exists(self, id: str) -> bool: ...
    def Insert(self, id: str, index: int) -> None: ...
    def RemoveSelf(self) -> None: ...
    def InsertSeparator(self, index: int) -> None: ...
    def RemoveAt(self, index: int) -> None: ...

class MenuToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IPopupMenuToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: Menu,
        menu: Infragistics.Windows.Ribbon.MenuTool,
    ) -> None: ...

    Count: int  # readonly
    DisplayStyle: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    )
    DisplayText: str
    Enabled: bool
    Image: str
    IsDropDownTool: bool  # readonly
    def __getitem__(
        self, id: str
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState: ...
    def __getitem__(
        self, index: int
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState: ...
    _Control: System.Windows.Controls.Control  # readonly

    def Add(self, id: str) -> None: ...
    def ShowPopupMenu(self) -> None: ...
    def BeforeToolDropdown(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        add: bool,
    ) -> None: ...
    def Clear(self) -> None: ...
    def IndexOf(self, id: str) -> int: ...
    def Remove(self, id: str) -> None: ...
    def Exists(self, id: str) -> bool: ...
    def RemoveChild(self, id: str) -> None: ...
    def Insert(self, id: str, index: int) -> None: ...
    def RemoveSelf(self) -> None: ...
    def InsertSeparator(self, index: int) -> None: ...
    def RemoveAt(self, index: int) -> None: ...

class PaneToolbar(
    IToolbar, Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbar
):  # Class
    def __init__(self, toolManager: IToolManager) -> None: ...

    Caption: str  # readonly
    IsMenuBar: bool  # readonly
    Visible: bool
    _ToolBar: System.Windows.Controls.ToolBar  # readonly

    def Contains(self, id: str) -> bool: ...
    def AddTool(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance: ...
    def InsertToolAfter(
        self, id: str, after: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance: ...
    def RemoveTool(self, id: str) -> None: ...
    def GetTool(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance: ...
    def GetToolState(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...

class RibbonGroupState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonGroup,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: Group,
        group: Infragistics.Windows.Ribbon.RibbonGroup,
    ) -> None: ...

    Caption: str
    Enabled: bool
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    ItemCount: int  # readonly
    Visible: bool
    _Control: System.Windows.Controls.Control  # readonly

    def AddTool(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def InsertToolAfter(
        self, id: str, idAfter: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def RemoveTool(self, id: str) -> None: ...
    def ContainsTool(self, id: str) -> bool: ...
    def RemoveChild(self, id: str) -> None: ...

class RibbonLabelToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: Label,
        label: Infragistics.Windows.Ribbon.LabelTool,
    ) -> None: ...

    Enabled: bool
    _Control: System.Windows.Controls.Control  # readonly

class RibbonState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbon
):  # Class
    def __init__(
        self, toolManager: IToolManager, ribbon: Infragistics.Windows.Ribbon.XamRibbon
    ) -> None: ...
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonTab: ...
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonTab: ...
    TabCount: int  # readonly

    def RemoveTab(self, id: str) -> None: ...
    def ContainsTab(self, id: str) -> bool: ...
    def AddTab(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonTab: ...
    def InsertTabAfter(
        self, id: str, idAfter: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonTab: ...

class RibbonTabState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonTab
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: TabItem,
        item: Infragistics.Windows.Ribbon.RibbonTabItem,
    ) -> None: ...

    Caption: str
    GroupCount: int  # readonly
    ID: str  # readonly
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonGroup: ...
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonGroup: ...
    Visible: bool

    def RemoveGroup(self, id: str) -> None: ...
    def ContainsGroup(self, id: str) -> bool: ...
    def AddGroup(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonGroup: ...
    def InsertGroupAfter(
        self, id: str, idAfter: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonGroup: ...

class SeparatorState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        sep: Separator,
        separator: System.Windows.Controls.Separator,
    ) -> None: ...

    Enabled: bool
    _Control: System.Windows.Controls.Control  # readonly

class SplitButtonToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IPopupMenuToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: Menu,
        button: Agilent.MassHunter.Quantitative.Controls.SplitToolButton,
    ) -> None: ...

    Count: int  # readonly
    Enabled: bool
    IsDropDownTool: bool  # readonly
    def __getitem__(
        self, id: str
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState: ...
    def __getitem__(
        self, index: int
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState: ...
    _Control: System.Windows.Controls.Control  # readonly

    def Add(self, id: str) -> None: ...
    def ShowPopupMenu(self) -> None: ...
    def BeforeToolDropdown(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        add: bool,
    ) -> None: ...
    def Clear(self) -> None: ...
    def IndexOf(self, id: str) -> int: ...
    def Remove(self, id: str) -> None: ...
    def Exists(self, id: str) -> bool: ...
    def Insert(self, id: str, index: int) -> None: ...
    def InsertSeparator(self, index: int) -> None: ...
    def RemoveAt(self, index: int) -> None: ...

class TextBoxToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ITextBoxToolState,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: TextBox,
        textBox: System.Windows.Controls.TextBox,
    ) -> None: ...

    Enabled: bool
    IsInEdit: bool  # readonly
    IsReadOnly: bool
    IsTextBox: bool  # readonly
    Text: str
    _Control: System.Windows.Controls.Control  # readonly

class TextEditorToolState(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ITextBoxToolState,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: TextBox,
        textEditor: Infragistics.Windows.Ribbon.TextEditorTool,
    ) -> None: ...

    Enabled: bool
    IsInEdit: bool  # readonly
    IsReadOnly: bool
    IsTextBox: bool  # readonly
    Text: str
    _Control: System.Windows.Controls.Control  # readonly

class ToggleButtonToolState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ICheckToolState,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.ButtonBaseToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
):  # Class
    def __init__(
        self,
        toolManager: IToolManager,
        definition: CheckButton,
        button: System.Windows.Controls.Primitives.ToggleButton,
    ) -> None: ...

    Checked: bool

    def RemoveSelf(self) -> None: ...

class ToolStateBase(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
):  # Class
    def __init__(self, toolManager: IToolManager, tool: ToolBase) -> None: ...

    Appearance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance
    )  # readonly
    BoldText: bool
    Bounds: System.Drawing.Rectangle  # readonly
    Checked: bool
    Definition: ToolBase  # readonly
    DisplayStyle: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    )
    DisplayText: str
    Enabled: bool
    Executing: bool  # readonly
    ID: str
    Id: str  # readonly
    Image: str
    IsComboBox: bool  # readonly
    IsDropDownTool: bool  # readonly
    IsEnabled: bool  # readonly
    IsTextBox: bool  # readonly
    MaxWidth: int
    MinWidth: int
    QueryingCanExecute: bool
    Separator: bool
    ToolManager: IToolManager  # readonly
    Tooltip: str
    Width: int
    _Control: System.Windows.Controls.Control  # readonly

    @staticmethod
    def RemoveTool(
        toolManager: IToolManager, obj: System.Windows.FrameworkElement
    ) -> bool: ...
    def RemoveSelf(self) -> None: ...
    def Dispose(self) -> None: ...
    def RemoveChild(self, id: str) -> None: ...
